.. django-galleryfield documentation master file, created by
   sphinx-quickstart on Thu Aug  5 19:19:30 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-galleryfield's documentation!
=================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quick_start
   intro
   about_demo
   customize
   fields
   views
   widget
   settings
   misc
   sources


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
